* This program is for the MH regressions for the SYPE panel

* clear memory
clear
clear mata
matrix drop _all
clear matrix
set maxvar 8000
set matsize 10000
set more off


*------------------------------------
/* CONTENTS
	1. Adjust dataset to long format
		1.1 Reshape file
		1.2 Set panel dimensions
		1.3 Recode some variables
	2. Regressions
		2.1 Table 1 - SRQ20 responses
		2.2 Figure 1 - cumulative MH sum index
		2.3 Figure 2 - First differenced MH sum
		2.4 Table 3 - XS wave-specific regressions
		2.5 Table 4 - FD regressions
	3. Interactions
		3.1 Men
		3.2 Women
*/
*------------------------------------


* start with MH descriptive datafile
use "MH_descriptive.dta", clear


*----------------------------------
/* 1. Configure panel dataset */
*----------------------------------

/* 1.1 Reshape file to long */

* only keep variables we need
gen Metro_region09 = Metro_region14 /* classifications are same across waves */

keep 	indid hh_id PSU	SHIAKHA	kismid	////
		expan_Elig	///
		sex male	///
		age09 age14 Age_Eligible2 agecat*	///
		Metro_region09 Metro_region14 region* 	///
		residency09 residency14 resid* movedhh ///
		educstatus09 educstatus14 levelcomp09 levelatt14 reason educreturn eductrans educdelay* educ2 ///
		wiq09 wiq14 wealth*	///
		student09 student14	///
		empsts09 empsts14 gotemp gotunemp	///
		OLFinschl09 OLFinschl14 olftounemp emptrans	///
		intdate09 intdate14	///
		muslim	hhsize09 hhsize14	///
		agefm09 agefm14 evrmar09 evrmar14 gotmarried	///
		numboy14 numgirl14 numkid14	///
		mh*09 mh*14 mhsum* poormh*
		

* rename all 2009 variables

local z "age Metro_region residency educstatus wiq empsts student OLFinschl intdate hhsize agefm evrmar mh22_ mh23_ mh24_ mh25_ mh26_ mh27_ mh28_ mh29_ mh30_ mh31_ mh32_ mh33_ mh34_ mh35_ mh36_ mh37_ mh38_ mh39_ mh40_ mh41_ poormh_ mhsum_"

foreach i of local z {
	rename `i'09 `i'9
}
						
						
* convert file wide to long format
reshape long age	///
		Metro_region ///
		residency	///
		educstatus educdelay ///
		wiq	///
		student	///
		empsts ///
		OLFinschl	///
		intdate	///
		hhsize	///
		agefm	///
		evrmar	///
		mh22_ mh23_ mh24_ mh25_ mh26_ mh27_ mh28_ mh29_ ///
		mh30_ mh31_ mh32_ mh33_ mh34_ mh35_ mh36_ mh37_ mh38_ mh39_ mh40_ mh41_ ///
		poormh_ mhsum_ ///
		f1allr f1menr f1womr	///
		f1allws f1menws f1womws,	i(indid) j(year)

foreach i of newlist mhsum poormh mh22 mh23 mh24 mh25 mh26 mh27 mh28 mh29 mh30 mh31 mh32 mh33 mh34 mh35 mh36 mh37 mh38 mh39 mh40 mh41 {
	rename `i'_ `i'
}		

rename Age_Eligible2 agegrp
		
/* 1.2 set panel dimensions */
destring indid, replace

xtset indid year
tsset indid year

/* 1.3 recode some variables */

* year
recode year 9=2009 14=2014

* create first-differenced variables
foreach i of varlist agegrp empsts evrmar {
	sort indid year
	bysort indid: gen `i'_fd = `i'[_n] - `i'[_n-1]
}

* save new file
save MH_panel.dta, replace


*--------------------
/* 2. Regressions */
* MH outcomes:
*	reg mhum 
*	logit poormh
* Controls: age, muslim, wealth, region, education, marital status, employment status
*	cluster(PSU)
*--------------------


* start with panel dataset
use MH_panel.dta, clear


* create standardized values of MHSUM FD
egen m = std(mhsum_fd) if male==1
egen f = std(mhsum_fd) if male==0
gen 	smhsum_fd = m if male==1
replace smhsum_fd = f if male==0
label var smhsum_fd "standardized (by sex) mhsum FD"
bysort male: sum smhsum_fd
drop m f


* create composite variable for educ level completed (09) and attended (14)
gen 	educlevel = levelcomp09 if year==2009
replace educlevel = levelatt14 if year==2014
label val educlevel educ_level

gen inschool = educstatus==2

* consolidate educ transition variables
recode eductrans 1=0 3=0 6=0	/* status stayed the same */
recode eductrans 5=7			/* combine into re-entered school */

* create labor transitions
foreach i of numlist 2009 2014 {
	gen x = empsts if year==`i'
	bysort indid: egen empsts`i' = max(x)
	drop x
	label val empsts`i' Emp_Sts
}
tab empsts2009 empsts2014

gen 	labortrans = 0 if empsts2009 == empsts2014
replace labortrans = 1 if inlist(empsts2009, 2, 3) 	& inlist(empsts2014, 1)
replace labortrans = 2 if inlist(empsts2009, 1)		& inlist(empsts2014, 2, 3)
replace labortrans = 3 if inlist(empsts2009, 3)		& inlist(empsts2014, 2)
replace labortrans = 4 if inlist(empsts2009, 2)		& inlist(empsts2014, 3)
label def labor_trans	0 "none" ///
						1 "U/OLF to employed" ///
						2 "employed to U/OLF" ///
						3 "OLF to Unemp" ///
						4 "Unemp to OLF"
label val labortrans labor_trans
label var labortrans "labor market transitions"

recode labortrans 4=2	/* combine trans to OLF */

* ID sample, make outreg file
* drop 1 person who has 1 missing response
drop if indid==16905

qui reg mhsum i.agegrp evrmar muslim i.educlevel inschool i.empsts i.wiq i.Metro_region if year==2009 & male==1 [pw=expan], cluster(PSU) ro
gen x = e(sample)
bys indid: egen sample09m = max(x)
drop x

qui reg mhsum i.agegrp evrmar muslim i.educlevel inschool i.empsts i.wiq i.Metro_region if year==2014 & male==1 [pw=expan], cluster(PSU) ro
gen x = e(sample)
bys indid: egen sample14m = max(x)
drop x

qui reg mhsum i.agegrp evrmar muslim i.educlevel inschool i.empsts i.wiq i.Metro_region if year==2009 & male==0 [pw=expan], cluster(PSU) ro
gen x = e(sample)
bys indid: egen sample09f = max(x)
drop x

qui: reg mhsum i.agegrp evrmar muslim i.educlevel inschool i.empsts i.wiq i.Metro_region if year==2014 & male==0 [pw=expan], cluster(PSU) ro
gen x = e(sample)
bys indid: egen sample14f = max(x)
drop x

gen samplem = sample14m==1 & sample09m==1
gen samplef = sample14f==1 & sample09f==1
gen sample = samplem==1 | samplef==1

/* 2.2 Fig 1: cdfs to export to excel */

* restrict to sample
keep if sample==1

tab mhsum if male==1 & year==2009 [aw=expan]
tab mhsum if male==1 & year==2014 [aw=expan]
tab mhsum if male==0 & year==2009 [aw=expan]
tab mhsum if male==0 & year==2014 [aw=expan]

* graph distribution
kdensity mhsum_fd if male==1 & agegrp==2 & year==2009 [aw=expan], ///
		addplot(kdensity mhsum_fd if male==1 & agegrp==3 & year==2009 [aw=expan] || ///
		kdensity mhsum_fd if male==1 & agegrp==4 & year==2009 [aw=expan])

kwallis mhsum_fd if male==1 & year==2009, by(agegrp) 

kdensity mhsum_fd if male==0 & agegrp==2 & year==2009 [aw=expan], ///
		addplot(kdensity mhsum_fd if male==0 & agegrp==3 & year==2009 [aw=expan] || ///
		kdensity mhsum_fd if male==0 & agegrp==4 & year==2009 [aw=expan])

kwallis mhsum_fd if male==0 & year==2009, by(agegrp) 

		
/* 2.3 Fig 2: FD MHSUM graphs */
tab mhsum_fd if male==1 [aw=expan]
tab mhsum_fd if male==0 [aw=expan]

bys agegrp: tab mhsum_fd if male==1 [aw=expan]
bys agegrp: tab mhsum_fd if male==0 [aw=expan]


* FD poormh
tab poormh_fd if male==1 [aw=expan]
tab poormh_fd if male==0 [aw=expan]


/* 2.1 Table 1: Descriptive table for MH items */

local mh "mh22 mh23 mh24 mh25 mh26 mh27 mh28 mh29 mh30 mh31 mh32 mh33 mh34 mh35 mh36 mh37 mh38 mh39 mh40 mh41 mhsum poormh"
tabstat `mh' if male==1 [aw=expan], by(year) stat(n mean) casewise c(s) nototal
tabstat `mh' if male==0 [aw=expan], by(year) stat(n mean) c(s) nototal


/* 2.4 Table 3 - wave-specific XS regressions */
set more off

* ID sample, make outreg file
qui: reg mhsum i.agegrp evrmar muslim i.educlevel inschool i.empsts i.wiq i.Metro_region [pw=expan], cluster(PSU) ro
outreg2 using multiv, auto(2) ctitle(ignore) replace

* 2009 wave - MEN
reg mhsum i.agegrp evrmar muslim i.educlevel inschool i.empsts i.wiq i.Metro_region if year==2009 & male==1 & sample==1 [pw=expan], cluster(PSU) ro
outreg2 using multiv, auto(2) ctitle(2009m) append

* 2014 wave - MEN
reg mhsum i.agegrp evrmar muslim i.educlevel inschool i.empsts i.wiq i.Metro_region if year==2014 & male==1 & sample [pw=expan], cluster(PSU) ro
outreg2 using multiv, auto(2) ctitle(2014m) append

* 2009 wave - WOMEN
reg mhsum i.agegrp evrmar muslim i.educlevel inschool i.empsts i.wiq i.Metro_region if year==2009 & male==0 & sample [pw=expan], cluster(PSU) ro
outreg2 using multiv, auto(2) ctitle(2009w) append

* 2014 wave - WOMEN
reg mhsum i.agegrp evrmar muslim i.educlevel inschool i.empsts i.wiq i.Metro_region if year==2014 & male==0 & sample [pw=expan], cluster(PSU) ro
outreg2 using multiv, auto(2) ctitle(2014w) append




/* 2.5 Table 4 - FD + transitions */
* focus on educ, marriage, labor

set more off
* set up outreg file
reg mhsum_fd i.educlevel i.eductrans inschool evrmar gotmarried i.empsts i.labortrans i.agegrp muslim i.wiq i.Metro_region if year==2009 & sample [pw=expan], cluster(PSU) ro
outreg2 using transitions, auto(2) ctitle(ignore) replace

* MEN
reg mhsum_fd i.educlevel i.eductrans inschool evrmar gotmarried i.empsts i.labortrans i.agegrp muslim i.wiq i.Metro_region if year==2009 & male==1 & sample [pw=expan], cluster(PSU) ro
outreg2 using transitions, auto(2) ctitle(all) append

* by age group
foreach i of numlist 2/4 {
	reg mhsum_fd i.educlevel i.eductrans inschool evrmar gotmarried i.empsts i.labortrans i.agegrp muslim i.wiq i.Metro_region if year==2009 & male==1 & sample & agegrp==`i' [pw=expan], cluster(PSU) ro
	outreg2 using transitions, auto(2) ctitle(all) append
}

* WOMEN
reg mhsum_fd i.educlevel i.eductrans inschool evrmar gotmarried i.empsts i.labortrans i.agegrp muslim i.wiq i.Metro_region if year==2009 & male==0 & sample [pw=expan], cluster(PSU) ro
outreg2 using transitions, auto(2) ctitle(all) append

foreach i of numlist 2/4 {
	reg mhsum_fd i.educlevel i.eductrans inschool evrmar gotmarried i.empsts i.labortrans i.agegrp muslim i.wiq i.Metro_region if year==2009 & male==0 & sample & agegrp==`i' [pw=expan], cluster(PSU) ro
	outreg2 using transitions, auto(2) ctitle(all) append
}



/* 2.6 Table 2 - sample characteritics */
qui for var educlevel eductrans empsts labortrans agegrp wiq Metro_region: tab X, gen(Xc)

xi: tabstat educlevelc1-educlevelc6 eductransc1-eductransc3 inschool evrmar gotmarried empstsc1-empstsc3 ///
	labortransc1-labortransc4 agegrpc1-agegrpc3 muslim wiqc1-wiqc5 Metro_regionc1-Metro_regionc6 if year==2009 & sample [aw=expan], ///
	by(male) stat(n mean) c(s) nototal casewise long

